Index: /trunk/src/VBox/Frontends/VirtualBox/src/globals/UICommon.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/globals/UICommon.cpp	(revision 86606)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/globals/UICommon.cpp	(revision 86607)
@@ -2578,7 +2578,7 @@
 void UICommon::notifyCloudMachineRegistered(const QString &strProviderShortName,
                                             const QString &strProfileName,
-                                            const CCloudMachine &comCloudMachine)
-{
-    emit sigCloudMachineRegistered(strProviderShortName, strProfileName, comCloudMachine, true /* select */);
+                                            const CCloudMachine &comMachine)
+{
+    emit sigCloudMachineRegistered(strProviderShortName, strProfileName, comMachine);
 }
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserAbstractModel.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserAbstractModel.cpp	(revision 86606)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserAbstractModel.cpp	(revision 86607)
@@ -693,6 +693,5 @@
 void UIChooserAbstractModel::sltCloudMachineRegistered(const QString &strProviderShortName,
                                                        const QString &strProfileName,
-                                                       const CCloudMachine &comMachine,
-                                                       bool fSelect)
+                                                       const CCloudMachine &comMachine)
 {
     /* Search for profile node: */
@@ -705,5 +704,5 @@
 
     /* Add new machine-item: */
-    addCloudMachineIntoTheTree(strProfileNodeName, comMachine, fSelect);
+    addCloudMachineIntoTheTree(strProfileNodeName, comMachine, true /* make it visible? */);
 
     /* Search for possible fake node: */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserAbstractModel.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserAbstractModel.h	(revision 86606)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserAbstractModel.h	(revision 86607)
@@ -166,10 +166,8 @@
         /** Handles cloud machine registering for @a comMachine.
           * @param  strProviderShortName  Brings provider short name.
-          * @param  strProfileName        Brings profile name.
-          * @param  fSelect               Brings whether registered machine should be selected. */
+          * @param  strProfileName        Brings profile name. */
         virtual void sltCloudMachineRegistered(const QString &strProviderShortName,
                                                const QString &strProfileName,
-                                               const CCloudMachine &comMachine,
-                                               bool fSelect);
+                                               const CCloudMachine &comMachine);
         /** Handles cloud machine registering/unregistering for machine with certain @a uMachineId.
           * @param  strProviderShortName  Brings provider short name.
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserModel.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserModel.cpp	(revision 86606)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserModel.cpp	(revision 86607)
@@ -1156,9 +1156,8 @@
 void UIChooserModel::sltCloudMachineRegistered(const QString &strProviderShortName,
                                                const QString &strProfileName,
-                                               const CCloudMachine &comMachine,
-                                               bool fSelect)
+                                               const CCloudMachine &comMachine)
 {
     /* Call to base-class: */
-    UIChooserAbstractModel::sltCloudMachineRegistered(strProviderShortName, strProfileName, comMachine, fSelect);
+    UIChooserAbstractModel::sltCloudMachineRegistered(strProviderShortName, strProfileName, comMachine);
 
     /* Rebuild tree for main root: */
@@ -1166,12 +1165,9 @@
 
     /* Select newly added item: */
-    if (fSelect)
-    {
-        QUuid uMachineId;
-        if (cloudMachineId(comMachine, uMachineId))
-            setSelectedItem(root()->searchForItem(uMachineId.toString(),
-                                                  UIChooserItemSearchFlag_Machine |
-                                                  UIChooserItemSearchFlag_ExactId));
-    }
+    QUuid uMachineId;
+    if (cloudMachineId(comMachine, uMachineId))
+        setSelectedItem(root()->searchForItem(uMachineId.toString(),
+                                              UIChooserItemSearchFlag_Machine |
+                                              UIChooserItemSearchFlag_ExactId));
 }
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserModel.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserModel.h	(revision 86606)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserModel.h	(revision 86607)
@@ -282,6 +282,5 @@
         virtual void sltCloudMachineRegistered(const QString &strProviderShortName,
                                                const QString &strProfileName,
-                                               const CCloudMachine &comMachine,
-                                               bool fSelect) /* override */;
+                                               const CCloudMachine &comMachine) /* override */;
         /** Handles cloud machine registering/unregistering for machine with certain @a uMachineId.
           * @param  strProviderShortName  Brings provider short name.

Index: /trunk/src/VBox/Frontends/VirtualBox/src/globals/UICommon.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/globals/UICommon.h	(revision 86606)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/globals/UICommon.h	(revision 86607)
@@ -91,10 +91,8 @@
           * @param  strProviderShortName  Brings provider short name.
           * @param  strProfileName        Brings profile name.
-          * @param  comCloudMachine       Brings cloud VM.
-          * @param  fSelect               Brings whether registered VM should be selected. */
+          * @param  comMachine            Brings cloud VM. */
         void sigCloudMachineRegistered(const QString &strProviderShortName,
                                        const QString &strProfileName,
-                                       const CCloudMachine &comCloudMachine,
-                                       const bool fSelect);
+                                       const CCloudMachine &comMachine);
         /** Notifies listeners about cloud VM registeration changed.
           * @param  strProviderShortName  Brings provider short name.
@@ -515,8 +513,8 @@
           * @param  strProviderShortName  Brings provider short name.
           * @param  strProfileName        Brings profile name.
           * @param  comCloudMachine       Brings cloud VM. */
         void notifyCloudMachineRegistered(const QString &strProviderShortName,
                                           const QString &strProfileName,
-                                          const CCloudMachine &comCloudMachine);
+                                          const CCloudMachine &comMachine);
         /** Notifies listeners about cloud VM registeration changed.
           * @param  strProviderShortName  Brings provider short name.
@@ -515,8 +513,8 @@
           * @param  strProviderShortName  Brings provider short name.
           * @param  strProfileName        Brings profile name.
-          * @param  comCloudMachine       Brings cloud VM. */
+          * @param  comMachine            Brings cloud VM. */
         void notifyCloudMachineRegistered(const QString &strProviderShortName,
                                           const QString &strProfileName,